==> haskell-http-client-tls-0.3.6.3-54-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-client-tls
version:              0.3.6.3
visibility:           public
id:                   http-client-tls-0.3.6.3-Fff9bfaN1MF9yyJi1Y1Qgj
key:                  http-client-tls-0.3.6.3-Fff9bfaN1MF9yyJi1Y1Qgj
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:
    http-client backend using the connection package and tls library

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.

category:             Network
abi:                  cabcaeff64622858c61b230f945d9ce4
exposed:              True
exposed-modules:      Network.HTTP.Client.TLS
import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-client-tls-0.3.6.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-client-tls-0.3.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/riscv64-linux-ghc-9.2.8/http-client-tls-0.3.6.3
hs-libraries:         HShttp-client-tls-0.3.6.3-Fff9bfaN1MF9yyJi1Y1Qgj
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-BBCkGXkqh3nGRz3m4HFNUT containers-0.6.5.1
    crypton-0.34-GAkeRvOUCMVBanETWHsxsb
    crypton-connection-0.3.2-5fbU10HgbouBeTpIgRb8kx
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp exceptions-0.10.4
    http-client-0.7.15-GFtj4cUUjxDGnZKaI4AjE1
    http-types-0.12.4-IbDJVwQVDeTAnHs7wyLMrJ
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    network-3.1.4.0-2VaTeXEywlqHC2pV2iXMik
    network-uri-2.6.4.2-Ey0TEfAHedB2qdPm3Bed9I text-1.2.5.0
    tls-1.8.0-3haHN370ZA3AIGLxPtgF82 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock

haddock-html:         /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-tls-0.3.6.3-66-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-client-tls
version:              0.3.6.3
visibility:           public
id:                   http-client-tls-0.3.6.3-7PKwybeQpZP3STjfZ1Ty3Q
key:                  http-client-tls-0.3.6.3-7PKwybeQpZP3STjfZ1Ty3Q
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:
    http-client backend using the connection package and tls library

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.

category:             Network
abi:                  14193e2e927f30d13648d3e0534f05c0
exposed:              True
exposed-modules:      Network.HTTP.Client.TLS
import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-client-tls-0.3.6.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-client-tls-0.3.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/riscv64-linux-ghc-9.2.8/http-client-tls-0.3.6.3
hs-libraries:         HShttp-client-tls-0.3.6.3-7PKwybeQpZP3STjfZ1Ty3Q
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh containers-0.6.5.1
    crypton-0.34-67uX59Sjjsw2dJbbUWUzWH
    crypton-connection-0.3.2-8RDci5jYdVsE9mwX2blZ3c
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp exceptions-0.10.4
    http-client-0.7.15-15pF87z30Lb260fGpQvD7x
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ
    network-uri-2.6.4.2-H8R7YZM4iJL108zVnRjrHh text-1.2.5.0
    tls-1.8.0-7h7yCI2XUOLCqAd7IRMHCz transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock

haddock-html:         /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
